.. _comment_cmd-name:

!!!!!!!!!!!
comment_cmd
!!!!!!!!!!!

.. meta::
   :keywords: comment_cmd,comment,command,syntax,purpose,example

.. index:: comment_cmd, comment

.. _comment_cmd-title:

Comment Command
###############

.. contents::
   :local:

.. _comment_cmd@Syntax:

Syntax
******
``{xrst_comment`` *text* ``}``

.. _comment_cmd@Purpose:

Purpose
*******
This command adds *text* to the xrst input file that
does not appear in the rst output file.

.. _comment_cmd@Example:

Example
*******
:ref:`comment_example-name`
